@@ -114,13 +114,14 @@ def main():
         cov.stop()
         omit = [
             '*/test*',
-            '*site-packages/pkg_resources*',
-            '*Python.framework*',
             tempfile.gettempdir() + '*']
         if 'termstyle' not in args.target:
             omit.append('*/termstyle*')
         if (args.target != 'green') and (not args.target.startswith('green.')):
-            omit.append('*site-packages*/green*')
+            omit.extend([
+            '*site-packages/pkg_resources*',
+            '*Python.framework*',
+            '*site-packages*/green*'])
         cov.report(file=stream, omit=omit)
     sys.exit(not result.wasSuccessful())
 
